==> opensaml-soap-api-4.0.1-sources.jar: org/opensaml/soap/wssecurity/AttributedDateTime.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.soap.wssecurity;

import java.time.Instant;

import javax.xml.namespace.QName;

import org.opensaml.core.xml.AttributeExtensibleXMLObject;
import org.opensaml.core.xml.schema.XSString;

/**
 * Interface for elements of complex type AttributedDateTime.
 * 
 */
public interface AttributedDateTime extends XSString, IdBearing, AttributeExtensibleXMLObject, WSSecurityObject  {

    /** Local name of the XSI type. */
    public static final String TYPE_LOCAL_NAME = "AttributedDateTime"; 
        
    /** QName of the XSI type. */
    public static final QName TYPE_NAME = 
        new QName(WSSecurityConstants.WSU_NS, TYPE_LOCAL_NAME, WSSecurityConstants.WSU_PREFIX);
    
    /**
     * Returns the Instant content or attribute value.
     * 
     * @return the {@link Instant} object.
     */
    public Instant getDateTime();

    /**
     * Sets the Instant content or attribute value.
     * 
     * @param dateTime
     *            the {@link Instant} object to set.
     */
    public void setDateTime(Instant dateTime);
    
}

==> opensaml-soap-api-5.1.4-sources.jar: org/opensaml/soap/wssecurity/AttributedDateTime.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.soap.wssecurity;

import java.time.Instant;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.xml.namespace.QName;

import org.opensaml.core.xml.AttributeExtensibleXMLObject;
import org.opensaml.core.xml.schema.XSString;

import net.shibboleth.shared.annotation.constraint.NotEmpty;

/**
 * Interface for elements of complex type AttributedDateTime.
 * 
 */
public interface AttributedDateTime extends XSString, IdBearing, AttributeExtensibleXMLObject, WSSecurityObject  {

    /** Local name of the XSI type. */
    @Nonnull @NotEmpty public static final String TYPE_LOCAL_NAME = "AttributedDateTime"; 
        
    /** QName of the XSI type. */
    @Nonnull public static final QName TYPE_NAME = 
        new QName(WSSecurityConstants.WSU_NS, TYPE_LOCAL_NAME, WSSecurityConstants.WSU_PREFIX);
    
    /**
     * Returns the Instant content or attribute value.
     * 
     * @return the {@link Instant} object.
     */
    @Nullable public Instant getDateTime();

    /**
     * Sets the Instant content or attribute value.
     * 
     * @param dateTime
     *            the {@link Instant} object to set.
     */
    public void setDateTime(@Nullable final Instant dateTime);
    
}
